import request from '@/utils/request'

/**
 * 加载标签列表
 */
export function getTags(params) {
    return request.get('/v2/api/tag', { params })
}

/**
 * 加载标签详情
 */
export function getTag(id) {
    return request.get('/v2/api/tag/' + id, {})
}

/**
 * 添加标签
 */
export function addTag(params) {
    return request.post('/v2/api/tag', params)
}

/**
 * 更新标签
 */
export function updateTag(id, params) {
    return request.put('/v2/api/tag/' + id, params)
}

/**
 * 删除标签
 */
export function deleteTag(id) {
    return request.delete('/v2/api/tag/' + id)
}

/**
 * 统计标签单位数
 */
export function statTag(id, params) {
    return request.get('/v2/api/tag/' + id + '/enforce_obj_count', {params})
}

/**
 * 批量统计标签单位数
 */
export function statBatchTag(params) {
    return request.get('/v2/api/tag/enforce_obj_count', {params})
}

/**
 * 查询规则列表
 */
export function queryRuleList(params) {
    return request.get('/v2/api/random_task_view', { params })
}

/**
 * 导出规则列表
 */
export function exportRuleList(params) {
    return request.get('/v2/api/random_task_view?' + params, { responseType: 'blob' })
}

/**
 * 查询规则详情
 */
export function queryRuleDetail(id) {
    return request.get(`/v2/api/random_task/${id}`)
}

/**
 * 查询规则限制参数
 */
export function queryRuleLimit() {
    return request.get('/v2/api/random_task/limit')
}

/**
 * 创建规则
 */
export function saveRule(params) {
    return request.post('/v2/api/random_task', params)
}

/**
 * 查询专项通知
 */
export function querySpecialNoticeList(params) {
    return request.get('/v2/api/random_task_notify_view', { params })
}

/**
 * 查询专项通知详情
 */
export function querySpecialNoticeDetail(id) {
    return request.get('/v2/api/random_task_notify/' + id)
}

/**
 * 创建专项通知
 */
export function addSpecialNotice(params) {
    return request.post('/v2/api/random_task_notify', params)
}

/**
 * 查询任务检查记录
 */
export function queryCheckList(params) {
    return request.get('/v2/api/enforce-job', { params })
}

// 查询执法人员信息列表
export function getExcutorList(params) {
  return request.get('/v2/api/sys_user/excutor', { params })
}

// 查询旧检查记录列表
export function getExcutorRecordList(params) {
  return request.get('/v2/api/enforce_old_job', { params })
}

// 查询旧检查记录详情
export function queryExcutorRecord(id) {
  return request.get('/v2/api/enforce_old_job/' + id)
}
